@@ -1,4 +1,4 @@
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 from django.core.management.base import BaseCommand, CommandParser
 from django.db.models import Q
 
@@ -13,11 +13,10 @@ class Command(BaseCommand):
     def handle(self, *args, **options):
         name = options["name"]
         passwd = options["password"]
-        users = User.objects.filter(Q(username=name) | Q(email=name))
+        users = get_user_model().objects.filter(Q(username=name) | Q(email=name))
         if not users:
             self.stdout.write("User not found")
         for user in users:
-            assert isinstance(user, User)
             user.set_password(passwd)
             user.save()
             self.stdout.write("User {} password set to {}".format(name, passwd))
